@@ -3,6 +3,7 @@ use tokio::io::{AsyncRead, AsyncReadExt, AsyncWrite, BufReader};
 use crate::tokio::io::AsyncWriteExt;
 use std::io::{self, Cursor, ErrorKind, Write};
 use std::pin::Pin;
+use std::sync::atomic::{AtomicU64, Ordering};
 use std::task::{Context, Poll};
 use dark_std::errors::Error;
 
@@ -19,19 +20,18 @@ use serde_json::to_vec;
 // rsp frame layout(ok=0,payload is string,ok=1,payload is data)
 // id(u64) + ok(u8) + len(u64) + payload/string ([u8; len])
 
-// max frame len
-const FRAME_MAX_LEN: u64 = 1024 * 1024;
+/// max frame len=10MB.
+pub static FRAME_MAX_LEN: AtomicU64 = AtomicU64::new(10 * 1024 * 1024);
 
 /// raw frame wrapper, low level protocol
-/// TODO: add check sum check
 #[derive(Debug)]
 pub struct Frame {
     /// frame id, req and rsp has the same id
     pub id: u64,
     /// is ok,false=0, true = 1
-    pub ok: u64,
+    pub ok: u8,
     /// payload data
-    data: Vec<u8>,
+    pub data: Vec<u8>,
 }
 
 impl Frame {
@@ -40,13 +40,13 @@ impl Frame {
         let id = r.read_u64().await?;
         debug!("decode id = {:?}", id);
 
-        let ok = r.read_u64().await?;
-        debug!("decode id = {:?}", ok);
+        let ok = r.read_u8().await?;
+        debug!("decode ok = {:?}", ok);
 
         let len = r.read_u64().await?;
         debug!("decode len = {:?}", len);
 
-        if len > FRAME_MAX_LEN {
+        if len > FRAME_MAX_LEN.load(Ordering::SeqCst) {
             let s = format!("decode too big frame length. len={}", len);
             error!("{}", s);
             return Err(io::Error::new(ErrorKind::InvalidInput, s));
@@ -57,7 +57,7 @@ impl Frame {
 
         let mut cursor = Cursor::new(vec![]);
         WriteBytesExt::write_u64::<BigEndian>(&mut cursor, id).unwrap();
-        WriteBytesExt::write_u64::<BigEndian>(&mut cursor, ok).unwrap();
+        WriteBytesExt::write_u8(&mut cursor, ok).unwrap();
         WriteBytesExt::write_u64::<BigEndian>(&mut cursor, len).unwrap();
         let mut datas = cursor.into_inner();
         datas.extend(data);
@@ -65,18 +65,11 @@ impl Frame {
         Ok(Frame { id, ok, data: datas })
     }
 
-    /// decode a request from the frame, this would return the req raw bufer
+    /// decode a request/response from the frame, this would return the req raw bufer
     /// you need to deserialized from it into the real type
-    pub fn decode_req(&self) -> &[u8] {
+    pub fn get_payload(&self) -> &[u8] {
         // skip the frame head
-        &self.data[24..]
-    }
-
-    /// decode a response from the frame, this would return the rsp raw bufer
-    /// you need to deserialized from it into the real type
-    pub fn decode_rsp(&self) -> &[u8] {
-        // skip the frame head
-        &self.data[24..]
+        &self.data[17..]
     }
 }
 
@@ -92,10 +85,10 @@ impl Default for ReqBuf {
 impl ReqBuf {
     pub fn new() -> Self {
         let mut buf = Vec::with_capacity(128);
-        buf.resize(24, 0);
+        buf.resize(17, 0);
         let mut cursor = Cursor::new(buf);
         // leave enough space to write id and len
-        cursor.set_position(24);
+        cursor.set_position(17);
         ReqBuf(cursor)
     }
 
@@ -103,17 +96,17 @@ impl ReqBuf {
     pub fn finish(self, id: u64, ok: bool) -> Vec<u8> {
         let mut cursor = self.0;
         let len = cursor.get_ref().len() as u64;
-        assert!(len <= FRAME_MAX_LEN);
+        assert!(len <= FRAME_MAX_LEN.load(Ordering::SeqCst));
 
         // write from start
         cursor.set_position(0);
         WriteBytesExt::write_u64::<BigEndian>(&mut cursor, id).unwrap();
         debug!("encode id = {:?}", id);
-        WriteBytesExt::write_u64::<BigEndian>(&mut cursor, ok as u64).unwrap();
-        debug!("encode id = {:?}", id);
+        WriteBytesExt::write_u8(&mut cursor, ok as u8).unwrap();
+        debug!("encode ok = {:?}", ok);
         // adjust the data length
-        WriteBytesExt::write_u64::<BigEndian>(&mut cursor, len - 24).unwrap();
-        debug!("encode len = {:?}", len);
+        WriteBytesExt::write_u64::<BigEndian>(&mut cursor, len - 17).unwrap();
+        debug!("encode len = {:?}", len - 17);
 
         let data = cursor.into_inner();
 
